"""VAST Admin MCP Server - MCP server for VAST Data administration tasks."""

from .functions import (
    list_clusters,
    list_performance,
)

__all__ = [
    "list_clusters",
    "list_performance",
]

